pub struct MockAccountsKeyManagementApi {
AccountsKeyManagementApi_expectations: MockAccountsKeyManagementApi_AccountsKeyManagementApi,
}Fields
AccountsKeyManagementApi_expectations: MockAccountsKeyManagementApi_AccountsKeyManagementApiImplementations
Sourceimpl MockAccountsKeyManagementApi
impl MockAccountsKeyManagementApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAccountsKeyManagementApi
impl MockAccountsKeyManagementApi
Sourcepub fn expect_get_key_connector_confirmation_details(
&mut self,
) -> &mut Expectation
pub fn expect_get_key_connector_confirmation_details( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_key_connector_confirmation_details method
Sourcepub fn expect_password_change_and_rotate_user_account_keys(
&mut self,
) -> &mut Expectation
pub fn expect_password_change_and_rotate_user_account_keys( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the password_change_and_rotate_user_account_keys method
Sourcepub fn expect_post_convert_to_key_connector(&mut self) -> &mut Expectation
pub fn expect_post_convert_to_key_connector(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_convert_to_key_connector method
Sourcepub fn expect_post_enroll_to_key_connector(&mut self) -> &mut Expectation
pub fn expect_post_enroll_to_key_connector(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_enroll_to_key_connector method
Sourcepub fn expect_post_set_key_connector_key(&mut self) -> &mut Expectation
pub fn expect_post_set_key_connector_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_set_key_connector_key method
Sourcepub fn expect_regenerate_keys(&mut self) -> &mut Expectation
pub fn expect_regenerate_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the regenerate_keys method
Sourcepub fn expect_rotate_user_keys(&mut self) -> &mut Expectation
pub fn expect_rotate_user_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the rotate_user_keys method